package com.ruoyi.web.controller.platform;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageInfo;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BaseParam;
import com.ruoyi.system.domain.QrLibrary;
import com.ruoyi.system.service.QrLibraryService;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 二维码Controller
 *
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/qr")
public class QrLibraryController extends BaseController {
    @Autowired
    private QrLibraryService qrLibraryService;

    /**
     * 查询二维码列表
     */
//    @PreAuthorize("@ss.hasPermi('platform:or:list')")
    @PostMapping("/list")
    public R<PageInfo<QrLibrary>> list(@RequestBody BaseParam param){
        IPage<QrLibrary> qrLibraryIPage = qrLibraryService.page(new Page<QrLibrary>().setCurrent(param.getCurrent()).setSize(param.getSize()),
                new LambdaQueryWrapper<QrLibrary>().like(param.getName()!=null,QrLibrary::getName,param.getName())
                        .eq(QrLibrary::getDelFlag,0));
        PageInfo<QrLibrary> pageInfo = new PageInfo<>();
        pageInfo.setRecords(qrLibraryIPage.getRecords());
        pageInfo.setTotal(qrLibraryIPage.getTotal());
        pageInfo.setSize(qrLibraryIPage.getSize());
        pageInfo.setCurrent(qrLibraryIPage.getCurrent());
        return R.ok(pageInfo);
    }


    /**
     * 获取二维码详细信息
     */
//    @PreAuthorize("@ss.hasPermi('platform:or:query')")
    @PostMapping(value = "/getInfo")
    public R<QrLibrary> getInfo(@RequestBody BaseParam param) {
        return R.ok(qrLibraryService.getOne(new LambdaQueryWrapper<QrLibrary>().eq(QrLibrary::getId,param.getId())
                .eq(QrLibrary::getDelFlag,"0"),false));
    }

    /**
     * 新增修改二维码
     */

//    @PreAuthorize("@ss.hasPermi('platform:or:add')")

    @Log(title = "红外遥控二维码", businessType = BusinessType.INSERT)
    @PostMapping("/addOrUpdate")
    public R<Boolean> add(@RequestBody QrLibrary param) {
        if (param.getId() != null) {
            param.setUpdateTime(DateUtils.getNowDate());
        }else {
            param.setCreateTime(DateUtils.getNowDate());
        }
        return R.ok(qrLibraryService.saveOrUpdate(param));
    }



    /**
     * 删除二维码
     */
//    @PreAuthorize("@ss.hasPermi('platform:or:remove')")
    @Log(title = "红外遥控二维码", businessType = BusinessType.DELETE)
	@PostMapping("/delete")
    public R<T> remove(@RequestBody BaseParam param) {
        boolean sta = qrLibraryService.removeById(param.getId());
        if (!sta){
            return R.fail("删除失败");
        }
        return R.ok();
    }
}
